import { useDataCheckStore, useAppStore } from "@/store";
import { StudentPage } from "./types";

export default function useTask() {
  const dataCheckStore = useDataCheckStore();

  function updatePageTasks(curPage: StudentPage) {
    if (!curPage) {
      dataCheckStore.setInfo({
        taskList:[],
        curTask: null,
      });
      return;
    }
  
    if (menuKey.value === "examNumber") {
      const taskList = [
        {
          id: `examNumber_${curPage.studentId}`
          type: "examNumber",
          questionIndex: 0,
          paperIndex: 0,
          pageIndex: 0,
          studentId: curPage.studentId,
          finished: false,
        },
      ];
      dataCheckStore.setInfo({
        taskList,
        curTask: taskList[0],
      });
      return;
    }
  
    const taskList = [];
    curPage.question?.result.map((item, index) => {
      if (!item || item.length > 1) {
        taskList.push({
          id: `question_${curPage.studentId}_${curPage.paperIndex}_${curPage.pageIndex}_${index}`,
          type: "question",
          questionIndex: index,
          paperIndex: curPage.paperIndex,
          pageIndex: curPage.pageIndex,
          studentId: curPage.studentId,
          finished: false,
        });
      }
    });
  
    dataCheckStore.setInfo({
      taskList,
      curTask: taskList[0],
    });
  }

  

  function updateNextUnfinishTask() {
    const task = dataCheckStore.taskList.find((item) => !item.finished);
    dataCheckStore.curTask = task || null;
  }

  function taskFinisheHandle() {
    const curTask = dataCheckStore.curTask;
    if (!curTask) {
      return;
    }
    curTask.finished = true;
    updateNextUnfinishTask();
  }

  return {
    updatePageTasks,
    updateNextUnfinishTask,
    taskFinisheHandle,
  };
}
